cordova.define("com-boc-igtb-plugin-utils.IGTBNative", function(require, exports, module) {
    var exec = require('cordova/exec');
    const isiOS = !!navigator.userAgent.match(/\(i[^;]+;( U;)? CPU.+Mac OS X/); //ios终端
   /**
     *推入新的控制器
     *loadurl 页面url全路径
     *示例   http://www.boc.cn/index.html/#/account
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.pushCdvMethod = function (loadurl, success, error) {
        exec(success, error, 'IGTBNative', 'pushCdvMethod', [loadurl]);
    };
    /**
     *推出当前控制器
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.popCdvMethod = function (success, error) {
        exec(success, error, 'IGTBNative', 'popCdvMethod');
    };

    /**
     *推出当前控制器显示频道页
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.popToRootCdvMethod = function (success, error) {
        exec(success, error, 'IGTBNative', 'popToRootCdvMethod');
    };

    /**
     * 打开一个webview页面
     * arg0 示例{loadurl:url,title:titlestring}
     * oadurl:要加载的url地址  title:页面标题(可不传)
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.pushWebviewMethod = function (arg0, success, error) {
        exec(success, error, 'IGTBNative', 'pushWebviewMethod', [arg0]);
    };

    /**
     * 获取设备网络是否可用    返回值 '0'为网络不可用  '1'为网络可用
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.networkStatus = function (success, error) {
        exec(success, error, 'IGTBNative', 'networkStatus');
    };

 /**
   *method 接口名称
   *header 需要上送的header，header可为null，为空时默认使用原生通讯中的header;不为null时，可以修改原生通讯中的header
   *params 需要上送的参数
   *id 非必输入项 指定通讯id，用于使用此id可以取消通讯
   *options 附加的参数，isLoading(boolean类型)标识是否弹出全局的loading框，true：弹出；false：不弹出，默认为false不弹出
   * success 接口调用成功回调函数
   * error 接口调用失败回调函数
   */
  exports.postRequest = function (method, header, params, options, success, error, id) {
    exec(success, error, 'IGTBNative', 'postRequest', [method, header, params, options, id]);
  };

    /**
     * 取消通讯
     * id 指定取消通讯的id
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.cancelRequest = function (id,success, error) {
        exec(success, error, 'IGTBNative', 'cancelRequest', [id]);
    };

    /**
     *会话异常情况需要重新登录
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.needLoginAgain = function (success, error) {
        exec(success, error, 'IGTBNative', 'needLoginAgain');
    };

    /**
     *调起原生登录
     *skipUrl 登录成功后直接跳转的路由url全路径 示例  http://22.11.26.46/#/account   可以不传，不传表示登录后不跳转页面
     * success 成功回调函数，返回登录信息
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.loginIGTB = function (skipUrl,success, error) {
        exec(success, error, 'IGTBNative', 'loginIGTB', [skipUrl]);
    };

    /**
     *获取用户信息
     * params   {neefRefresh: '1'}  neefRefresh 是否需要刷新客户信息 1：需要  非1：不需要
     * success 成功callback,返回用户信息
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.getUserInfo = function (params,success, error) {
        exec(success, error, 'IGTBNative', 'getUserInfo', [params]);
    };

    /**
     *进入扫一扫功能
     *success 成功回调函数,返回扫描出的二维码信息（可不传，不传时表示页面不用处理扫描出的结果）
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.qrCodeScan = function (success, error) {
        var callbackflag = success ? '1' : '0';
        exec(success, error, 'IGTBNative', 'qrCodeScan',[callbackflag]);
    };

    /**
     * 获取二维码图片
     * qrcodestr 用于生成二维码图片的信息
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.getQrCodeImage = function (qrcodestr,success, error) {
        exec(success, error, 'IGTBNative', 'getQrCodeImage', [qrcodestr]);
    };

     /**
     * 保存图片到本地相册
     *imagebase64str 需要保存的图片base64之后的数据
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.saveToPhotos = function (imagebase64str,success, error) {
        exec(success, error, 'IGTBNative', 'saveToPhotos', [imagebase64str]);
    };

     /**
     * 保存局部图片到本地相册
     * params {left: 0, top: 0, right: 100,bottom: 100，isSavePicture=true}
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
     exports.saveToPhotosWithMark = function(params,success,error){
         exec(success,error,'IGTBNative','saveToPhotosWithMark',[params]);
     };


     /**
     *微信分享
     *shareType 微信分享的类型 文字分享:'0' 分享图片:'1'  网页分享:'2'
     *shareData 微信分享的数据
     *scene  发送的目标场景  分享到对话:'0' 分享到朋友圈:'1'  默认为分享到对话
     *
     *shareType为'0' 文字类型分享shareData设置内容，{message: '分享文本内容'}
     *shareType为'1' 图片类型分享shareData设置内容，{image:'分享图片的路径'}
     *shareType为'2' 网页类型分享shareData设置内容，{webPageUrl:'分享网页的路径', title:'标题', description:'描述', thumbImage:'缩略图'}
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.wxShare = function (shareType, shareData, scene,success, error) {
        scene = scene ? scene : '0';
        exec(success, error, 'IGTBNative', 'wxShare', [shareType, shareData, scene]);
    };

     /**
     *设置状态栏字体颜色，并同时返回状态栏高度用于页面适配
     *statusBarStyle  '0'为黑色字体 '1'为白色字体  不修改字体颜色时可不传
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.statusBarHeight = function (statusBarStyle,success, error) {
        exec(success, error, 'IGTBNative', 'statusBarHeight', [statusBarStyle]);
    };


    /**
     * 刷新TabPage页
     * pageId （'0' 首页, '1' 工作台, '2' 我的）可不传，频道页全部刷新
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.refreshTabPage = function (pageId,success, error) {
        exec(success, error, 'IGTBNative', 'refreshTabPage', [pageId]);
    };

    /**
     * 查询指纹登录开通状态
     * success 查询成功回调函数  返回参数 {type: '1', hasBioReg: '0'} （type: 0指纹  1人脸 ,hasBioReg: 0 未开通 1已开通 2设备不支持）
     * error 查询错误回调函数
     */
    exports.isFingerPrintOpen = function (success,error) {
        exec(success, error, 'IGTBNative', 'isFingerPrintOpen', null);
    };

    /**
     * 开通指纹登录
     * success  开通成功回调函数
     * error  开通失败回调函数
     */
    exports.openFingerPrintLogin = function (success,error) {
        exec(success, error, 'IGTBNative', 'openFingerPrintLogin', null);
    };

    /**
     * 关闭指纹登录
     * success 关闭成功回调函数
     * error 关闭异常回调函数
     */
    exports.closeFingerPrintLogin = function (success,error) {
        exec(success, error, 'IGTBNative', 'closeFingerPrintLogin', null);
    };

    /**
     * 关闭硬件绑定
     * success 关闭成功回调函数
     * error 关闭异常回调函数
     */
    exports.closeDeviceBind = function (success,error) {
        exec(success, error, 'IGTBNative', 'closeDeviceBind', null);
    };

    /** 设置频道页nav和tabbar遮罩
     * color 遮罩颜色  'rgba(0,0,0,0.5)'
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.setNavAndTabBarMaskWithColor = function (color,success, error) {
        exec(success,error, 'IGTBNative', 'setNavAndTabBarMaskWithColor', [color]);
    };

    /**
     * 移除频道页nav和tabbar遮罩
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.removeNavAndTabBarMask = function (success, error) {
        exec(success,error, 'IGTBNative', 'removeNavAndTabBarMask', null);
    };

    /**
     * 添加一个消息通知观察者
     * pageId 观察的页面key
     * callback 接受观察的回调函数
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.addNotificationObserver = function (pageId,callback,success, error) {
        // 创建随机数
        var arr = ['A','B','C','D','E','F','G','H','I','J','K','L','M','N','O','P','Q','R','S','T','U','V','W','X','Y','Z'];
        var idvalue ='';
        for(var i=0; i<5; i++){
            idvalue += arr[Math.floor(Math.random()*26)];
        }
        var timeNow = Date.now();
        var functionName = idvalue + timeNow;
        window[functionName] = callback;
        exec(success, error, 'IGTBNative', 'addNotificationObserver', [pageId, functionName]);
    };

    /**
     * 发送给指定key的消息通知
     * pageId 观察的页面key
     * params 传递参数
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.postNotification = function (pageId, params,success, error) {
        exec(success, error, 'IGTBNative', 'postNotification', [pageId,JSON.stringify(params)]);
    };

     /**
     * 打开隐私政策
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.pushPrivacyPolicy = function (success, error) {
        exec(success, error, 'IGTBNative', 'pushPrivacyPolicy', null);
    };

    /**
     * 打开关于我们
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.pushAboutUs = function (success, error) {
        exec(success, error, 'IGTBNative', 'pushAboutUs', null);
    };

    /**
     * 取消隐私政策
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.cancelPrivacyPolicy = function (success, error) {
        exec(success, error, 'IGTBNative', 'cancelPrivacyPolicy', null);
    };

     /**
     * 扫码登录
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.qrCodeScanLogin = function (success, error) {
        exec(success, error, 'IGTBNative', 'qrCodeScanLogin', null);
    };

    /**
     * 获取消息通知列表
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.getNotificationList = function (params,success, error){
        exec(success, error, 'IGTBNative', 'getNotificationList', [params]);
    };

     /**
      *返回系统版本号信息
      * success 参数返回app版本
      * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
      */
     exports.getAppVersion = function (success, error) {
        exec(success, error, 'IGTBNative', 'getAppVersion', null);
    };

    /**
     * 调起在线客服页面
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）     */
    exports.callChatActivity = function (success, error) {
        exec(success, error, 'IGTBNative', 'callChatActivity', null);
    };

    /**
     * 调起蓝牙key管理页面，此插件适用用安全中心数字证书管理功能
     * 调用此插件后，与蓝牙key的交互均由原生端完成
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.callBluetoothKeyManage = function(success, error){
        exec(success,error,'IGTBNative','callBluetoothKeyManage',null);
    };

    /**
     * 使用数字证书对数据加签
     * certDN 预交易返回，直接上送即可
     * plainData 待加签的原始数据
     * success 成功的回调   内容为json格式 包含signData(加签后数据)
     * error 错误的回调，内容为json格式  包含code,message
     */
    exports.signDataWithKey = function(certDN,plainData,success,error){
        exec(success,error,'IGTBNative','signDataWithKey',[certDN,plainData]);
    };

    /**
     * 显示loading，5s后显示关闭按钮
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.openGlobalLoading = function(success, error){
        exec(success,error,'IGTBNative','openGlobalLoading',null);
    };

    /**
     * 关闭loading
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.closeGlobalLoading = function(success, error){
        exec(success,error,'IGTBNative','closeGlobalLoading',null);
    };

    /**
     * 打开ios的webview下拉上拉自带弹跳
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.openBounces = function(success, error){
        if(isiOS){
            exec(success,error,'IGTBNative','openBounces',null);
        }
    };

    /**
     * 关闭ios的webview下拉上拉自带弹跳
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
    exports.closeBounces = function(success, error){
        if(isiOS){
            exec(success,error,'IGTBNative','closeBounces',null);
        }
    };
  /**
  * 打开回单验证页面
    * success 成功回调函数
    * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
   */
    exports.receiptVerify = function (success, error) {
        exec(success, error, 'IGTBNative', 'receiptVerify', null);
    };
   /**
     * 我的页面静态修改密码
     * success 成功回调函数
     * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
     */
     exports.fixPassword = function (success, error) {
         exec(success, error, 'IGTBNative', 'fixPassword', null);
     };
    /**
      * 安全工具选择
      * serviceId 服务id
      * params   {"serviceId": 'EB9995',random: '1',conversationId:'conversationId'}
      * success 成功回调函数
      * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
      * 返回参数 { securityId:"1"} 代表支持的安全工具列表
      * 0 无支持的安全工具
      * 1 代表CA
      * 4 代表Etoken
      */
       exports.mobileSecurityListQuery = function (serviceId,success, error) {
          exec(success, error, 'IGTBNative', 'mobileSecurityListQuery', [serviceId]);
        };

    /**
      * 手机安全工具首次认证
      * params   {"loadurl": 'http://www.boc.cn/index.html/#/account'}  loadurl 页面url全路径 上传url则会加强认证成功之后，直接推送H5页面，不上送则只做加强认证
      * success 成功回调函数
      * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
      * 返回参数 { securityId:"1"} 代表当时认证的的安全工具
      * securityId =1 代表CA
      * securityId =4 代表Etoken
      */
       exports.mobileSecFirstCert = function (params,success, error) {
          exec(success, error, 'IGTBNative', 'mobileSecFirstCert', [params]);
        };
     /**
        * 使用Etoken进行加签
        * params   {random: '1'}
        * success 成功的回调   内容为json格式 {otp: '1',otp_RC: '1',activ: '1'}
        * error 错误的回调
        */
    exports.signDataWithEtoken = function(params,success,error){
      exec(success,error,'IGTBNative','signDataWithEtoken',[params]);
    };
       /**
       * 使用Sms进行加签
       * params   {random: '1',conversationId:'conversationId'}
       * success 成功的回调   内容为json格式 {smc: '1',smc_RC: '1',activ: '1'}
       * error 错误的回调
       */
       exports.signDataWithSms = function(params,success,error){
         exec(success,error,'IGTBNative','signDataWithSms',[params]);
       };

   /**
      * 根据前段上送数据获取照片流
      * params  {imageType: '1',option:"0"} 1 拍照 0 相册   option 是否多选 单选 0/空  多选 1
      * success 成功的回调   内容为json格式{ piclist:[{imageInfo: '1',imagePath: '1',uuid: '1',fileOffset: '0' ，packetSize: '10240'}]}　
      *                      imageInfo 照片流base64  imagePath 照片路径  uuid 索引uuidfileOffset 偏移量  packetSize 文件大小 单位是B
      * error  失败回调函数  内容为json格式 {code:'001', message:"unknown"}
     */
       exports.getImageInfo = function(params,success,error){
         exec(success,error,'IGTBNative','getImageInfo',[params]);
       };
   　/**
        * 根据前段上送数据进行活体检测并返回最佳照片流
        * params  {errorNum: '1'} errorNum 失败次数，当H5上传照片错误，重新调用此值的时候，需要加1，当为3的时候，可以提过活体检测
        * success 成功的回调　　内容为json格式 {imageInfo: '1',errorNum: '1',uuid: '1',  fileOffset: '1', packetSize: '1'}　 imageInfo 照片流base64  errorNum 失败次数  uuid 索引 fileOffset 偏移量  packetSize 文件大小 单位是B
        * error  失败回调函数  内容为json格式 {code:'001', message:"unknown"}，返回错误的时候，代表扫描3次失败
       */
         exports.getLiveCheckImage = function(params,success,error){
           exec(success,error,'IGTBNative','getLiveCheckImage',[params]);
         };
  　　 /**
          * 视频录制.返回分包list
          * params  {packetSize: '10'，videodes: 'xxx'} 每包文件的大小 单位是B 前段自行设定,必输
                                       videodes  录制视频时候客户需要读的文案
          * success 成功的回调　内容为json格式 {filePath：“xxx”,packets:[{fileOffset: 0 ，packetSize: 10}，{fileOffset: 10 ，packetSize: 10}]}　
          *                     filePath  文件路径   fileOffset 数据包起始偏移量 packetSize 当前上传文件的大小，单位是B
          * error  失败回调函数 内容为json格式 {code:'001', message:"unknown"} code=003的时候，是取消视频录制，回到列表页面
        */
         exports.getVideoRecorderList = function(params,success,error){
              exec(success,error,'IGTBNative','getVideoRecorderList',[params]);
         };
        /**
          * 根据视频录制返回的文件list，返回视频流
          * params  {filePath：“xxx”,fileOffset：“xxx”,packetSize：“xxx”}  filePath  文件路径   fileOffset 数据包起始偏移量 packetSize 当前上传文件的大小，单位是B
          * success 成功的回调　 内容视频流（类型ArrayBuffer）
          * error  失败回调函数  内容为json格式 {code:'001', message:"unknown"}
           */
          exports.getVideoRecorderBuffer = function(params,success,error){
             exec(success,error,'IGTBNative','getVideoRecorderBuffer',[params]);
          };
         /**
          * 进度条控件

          *

          * params {progress: '10', description: '上传中...', errorMsg: '上传失败',afterDelay: '2',isCancelable: false}
          * params.progress 进度,0-100,100时自动关闭
          * params.description 显示的描述信息
          * params.errorMsg 错误时的报错信息，非必输
          * params.afterDelay 几秒后关闭，默认0，非必输
          * params.isCancelable 是否可以取消

          *

          * success 成功的回调　 进度100返回
          * error  失败回调函数  内容为json格式 {code:'001', message:"unknown"}
        */
       exports.showProgressBar = function(params,success,error){
            exec(success,error,'IGTBNative','showProgressBar',[params]);
        };

        /**
         * 推出当前控制器显示频道页
         * arg0 示例{tabflag:0} 0 首页 1工作台 2 我的  送空就是栈底是原生哪个页面就回到哪个页面 ，不做跳转处理,
         * success 成功回调函数
         * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
         */
        exports.popToRootCdvMethod = function (arg0,success, error) {
            exec(success, error, 'IGTBNative', 'popToRootCdvMethod', [arg0]);
        };
        /**
         * 更新角色信息
         * CustSwitch 接口返回数据
         * success 成功回调函数
         * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
         */
        exports.updateCustMethod = function (params,success, error) {
            exec(success, error, 'IGTBNative', 'updateCustMethod', [params]);
        };

        /**
         * 定位（腾讯sdk）
         * success 成功回调函数
         * error 失败回调函数 （返回json字符串 {code:'001', message:"unknown"}）
         */
        exports.getLocation = function (success, error) {
          exec(success, error, 'IGTBNative', 'getLocation', null);
        };




     });
